==> lpirfs_0.2.0.tgz: lpirfs/NEWS.md <==

# lpirfs 0.2.0

* The dependency on the external JST data set has been removed by commenting out the examples for
the panel functions. Now, the JST data set has to be downloaded by the user first, before running 
the examples for the panel functions.


# lpirfs 0.1.9

* Removed a dependency in the vignette so that it can be build again. 


# lpirfs 0.1.8

* Fixed tests and deprecated functions to be compatible with new dplyr 1.0.0.

* Fixed an issue to correctly show summary statistics


# lpirfs 0.1.7


* Resolved an integer/double issue with an Rcpp function so that the package can also be installed on Oracle Solaris. 

* Added an option to show how many lags were chosen when an information criterion has been used.
  


# lpirfs 0.1.6


* New S3 methods for all main functions to use *summary()* and *plot()* 

* More flexible options for the HAC estimators, such as pre-whitening, sample 
  size adjustment, etc. 

* New vignette

* Updated documentation
  


# lpirfs 0.1.5

* Fixed a bug for *lp_lin_panel()* and *lp_nl_panel()* regarding the construction of the 
  endogenous and exogenous variables.

* Fixed a bug for *lp_nl_panel()* when using the switching variable. 

* Fixed a bug for *lp_lin_panel()* and *lp_nl_panel()* when a pooling model is specified.

* New checks for *lp_lin_panel()* and *lp_nl_panel()* to see whether shock variable has been dropped during estimation, 
  potentially because of co-linearity or identification issues.
  
* *lp_nl_panel()* now returns the (transformed) switching variable as a *tibble* along with the original data
  for comparabaility.
  
* Updated documentation.  

* Updated examples.
  

# lpirfs 0.1.4

* Added two functions to estimate linear and nonlinear irfs for panel data.

* Added an option to choose whether to use lagged values of the switching variable in 
  nonlinear models. 

* Added an option to use a dummy approach for the nonlinear models.

* Deleted messages about how models are estimated (e.g. with or without exogenous data).

* Changed input name in `lp_lin_iv()` for consistency:

function | old input name | new input name
:--------|:-------------  |:------------- 
`lp_lin_iv()` | `twosls`     | `use_twosls`



# lpirfs 0.1.3

* Included an option to conduct 2SLS with *lp_lin_iv*.

* Included an option to set the lag length of the endogenous variables in *lp_lin_iv* and *lp_nl_iv* to zero.

* Deleted the deprecated plot functions *plot_lin_irfs* and *plot_nl_irfs*.

* Improved documentation.

* Changed input names in `lp_lin_iv()` and `lp_nl_iv()` for consistency:

function | old input name | new input name
:--------|:-------------  |:------------- 
`lp_lin_iv()` | `instr`     | `shock`
`lp_nl_iv()`  | `instr`     | `shock`


# lpirfs 0.1.2

* Fixed an error in `lp_nl()` when lags are chosen by a lag length criterion. 
  Version 0.1.1 chooses lags based on linear instead of 
  nonlinear data.

* Removed the dependency on the *vars* package. 

* `lp_lin()` and `lp_nl()` now allow to include exogenous variables and exogenous variables
  with contemporaneous impact. 

* `plot_lin_irfs()` and `plot_nl_irfs()` are deprecated and have been 
  replaced by `plot_lin()` and `plot_nl()`.

* Two new functions named `lp_lin_iv()` and `lp_nl_iv()` allow to estimate 
  linear and nonlinear impulse responses with identified shocks (instrument variables).

* Input names in `lp_lin()` and `lp_nl()` have been changed for consistency:

function | old input name | new input name
:--------|:-------------  |:------------- 
`lp_lin()` | `lags_lin`     | `lags_endog_lin`
`lp_nl()`  | `lags_lin`     | `lags_endog_lin`
`lp_nl()`  | `lags_nl`      | `lags_endog_nl`
`lp_nl()`  | `hp_filter`    | `use_hp`



# lpirfs 0.1.1

* The dependency on the *mFilter* package is removed. `hp_filter()` is now written in C++ to improve efficiency. 

* A problem with a C++ function is resolved so that the package can also be installed on Oracle Solaris. 

* Renamed functions:

original name | new name |
:--------|:------------- 
`lm_function`       | `get_resids_ols` 
`reduced_var`       | `get_mat_chol`
`find_lag_c`        | `get_vals_lagcrit`
`newey_west_c`      | `newey_west`
`switching_series`  | `get_vals_switching`
 

# lpirfs 0.1.0
* First CRAN release.

==> lpirfs_0.2.3.tgz: lpirfs/NEWS.md <==
# lpirfs 0.2.3

* Fixed bug [#27](https://github.com/AdaemmerP/lpirfs/issues/27#issue-1656283271).
* Added additional output for panel functions. Now, the full plm-objects are returned in addition to summary statistics. 
* Updated mail address. 

# lpirfs 0.2.2

* Disabled the possibility *lags_exog* = 0 for functions `lp_lin()`, `lp_nl()`, `lp_lin_iv()` and `lp_nl_iv()`. Solely *contemp_data* should be used for exogenous data with contemporaneous impact. 

* Updated documentation for functions `lp_lin()`, `lp_nl()`, `lp_lin_iv()` and `lp_nl_iv()` regardings *exog_data* and *lags_exog*.  

# lpirfs 0.2.1

* Added the options *cumul_mult = FALSE/TRUE* for the functions *lp_lin_iv* and *lp_nl_iv*. The default is FALSE.

* Updated CITATION to use the paper by Adämmer (2019) published in The R Journal.

* Updated documentation.

# lpirfs 0.2.0

* The dependency on the external JST data set has been removed by commenting out the examples for the panel functions. Now, the JST data set has to be downloaded by the user first, before running the examples for the panel functions.


# lpirfs 0.1.9

* Removed a dependency in the vignette so that it can be build again. 


# lpirfs 0.1.8

* Fixed tests and deprecated functions to be compatible with new dplyr 1.0.0.

* Fixed an issue to correctly show summary statistics


# lpirfs 0.1.7


* Resolved an integer/double issue with an Rcpp function so that the package can also be installed on Oracle Solaris. 

* Added an option to show how many lags were chosen when an information criterion has been used.
  


# lpirfs 0.1.6


* New S3 methods for all main functions to use `summary()` and `plot()` 

* More flexible options for the HAC estimators, such as pre-whitening, sample 
  size adjustment, etc. 

* New vignette

* Updated documentation
  


# lpirfs 0.1.5

* Fixed a bug for `lp_lin_panel()` and `lp_nl_panel()` regarding the construction of the 
  endogenous and exogenous variables.

* Fixed a bug for `lp_nl_panel()` when using the switching variable. 

* Fixed a bug for `lp_lin_panel()` and `lp_nl_panel()` when a pooling model is specified.

* New checks for `lp_lin_panel()` and `lp_nl_panel()` to see whether shock variable has been dropped during estimation, 
  potentially because of co-linearity or identification issues.
  
* `lp_nl_panel()` now returns the (transformed) switching variable as a tibble along with the original data
  for comparabaility.
  
* Updated documentation.  

* Updated examples.
  

# lpirfs 0.1.4

* Added two functions to estimate linear and nonlinear irfs for panel data.

* Added an option to choose whether to use lagged values of the switching variable in 
  nonlinear models. 

* Added an option to use a dummy approach for the nonlinear models.

* Deleted messages about how models are estimated (e.g. with or without exogenous data).

* Changed input name in `lp_lin_iv()` for consistency:

function | old input name | new input name
:--------|:-------------  |:------------- 
`lp_lin_iv()` | `twosls`     | `use_twosls`



# lpirfs 0.1.3

* Included an option to conduct 2SLS with `lp_lin_iv()`.

* Included an option to set the lag length of the endogenous variables in `lp_lin_iv()` and `lp_nl_iv()` to zero.

* Deleted the deprecated plot functions `plot_lin_irfs()` and `plot_nl_irfs()`.

* Improved documentation.

* Changed input names in `lp_lin_iv()` and `lp_nl_iv()` for consistency:

function | old input name | new input name
:--------|:-------------  |:------------- 
`lp_lin_iv()` | `instr`     | `shock`
`lp_nl_iv()`  | `instr`     | `shock`


# lpirfs 0.1.2

* Fixed an error in `lp_nl()` when lags are chosen by a lag length criterion. 
  Version 0.1.1 chooses lags based on linear instead of 
  nonlinear data.

* Removed the dependency on the *vars* package. 

* `lp_lin()` and `lp_nl()` now allow to include exogenous variables and exogenous variables
  with contemporaneous impact. 

* `plot_lin_irfs()` and `plot_nl_irfs()` are deprecated and have been 
  replaced by `plot_lin()` and `plot_nl()`.

* Two new functions named `lp_lin_iv()` and `lp_nl_iv()` allow to estimate 
  linear and nonlinear impulse responses with identified shocks (instrument variables).

* Input names in `lp_lin()` and `lp_nl()` have been changed for consistency:

function | old input name | new input name
:--------|:-------------  |:------------- 
`lp_lin()` | `lags_lin`     | `lags_endog_lin`
`lp_nl()`  | `lags_lin`     | `lags_endog_lin`
`lp_nl()`  | `lags_nl`      | `lags_endog_nl`
`lp_nl()`  | `hp_filter`    | `use_hp`



# lpirfs 0.1.1

* The dependency on the *mFilter* package is removed. `hp_filter()` is now written in C++ to improve efficiency. 

* A problem with a C++ function is resolved so that the package can also be installed on Oracle Solaris. 

* Renamed functions:

original name | new name |
:--------|:------------- 
`lm_function`       | `get_resids_ols` 
`reduced_var`       | `get_mat_chol`
`find_lag_c`        | `get_vals_lagcrit`
`newey_west_c`      | `newey_west`
`switching_series`  | `get_vals_switching`
 

# lpirfs 0.1.0
* First CRAN release.
